@@ -11,9 +11,9 @@
 #include "abstractfile/indexercommon.h"
 
 #include "filescanner.h"
+#include "elisa_settings.h"
 
 #include <QThread>
-#include <QHash>
 #include <QFileInfo>
 #include <QFile>
 #include <QDir>
@@ -72,10 +72,12 @@ AbstractFileListing::~AbstractFileListing()
 void AbstractFileListing::init()
 {
     qCDebug(orgKdeElisaIndexer()) << "AbstractFileListing::init";
-
     d->mIsActive = true;
 
-    Q_EMIT askRestoredTracks();
+    const bool autoScan = Elisa::ElisaConfiguration::self()->scanAtStartup();
+    if (autoScan) {
+        Q_EMIT askRestoredTracks();
+    }
 }
 
 void AbstractFileListing::stop()
@@ -149,7 +151,7 @@ void AbstractFileListing::scanDirectory(DataTypes::ListTrackDataType &newFiles,
         }
     }
 
-    auto &currentDirectoryListingFiles = d->mDiscoveredFiles[path];
+    auto currentDirectoryListingFiles = d->mDiscoveredFiles[path];
 
     auto currentFilesList = QSet<QUrl>();
 
@@ -198,12 +200,6 @@ void AbstractFileListing::scanDirectory(DataTypes::ListTrackDataType &newFiles,
     for (const auto &newFilePath : currentFilesList) {
         QFileInfo oneEntry(newFilePath.toLocalFile());
 
-        auto itFilePath = std::find(currentDirectoryListingFiles.begin(), currentDirectoryListingFiles.end(), QPair<QUrl, bool>{newFilePath, oneEntry.isFile()});
-
-        if (itFilePath != currentDirectoryListingFiles.end()) {
-            continue;
-        }
-
         if (oneEntry.isDir()) {
             addFileInDirectory(newFilePath, path, WatchChangedDirectories | WatchChangedFiles);
             scanDirectory(newFiles, newFilePath, WatchChangedDirectories | WatchChangedFiles);
