@@ -13,6 +13,7 @@
 
 #include <QAudio>
 #include <QDir>
+#include <QGuiApplication>
 
 #if defined Q_OS_WIN
 
@@ -95,7 +96,7 @@ AudioWrapper::AudioWrapper(QObject *parent) : QObject(parent), d(std::make_uniqu
 {
     d->mParent = this;
     d->mInstance = libvlc_new(0, nullptr);
-    libvlc_set_user_agent(d->mInstance, "elisa", "Elisa Music Player");
+    libvlc_set_user_agent(d->mInstance, QGuiApplication::applicationDisplayName().toUtf8().constData(), "Elisa Music Player");
     libvlc_set_app_id(d->mInstance, "org.kde.elisa", ELISA_VERSION_STRING, "elisa");
 
     d->mPlayer = libvlc_media_player_new(d->mInstance);
