@@ -10,16 +10,15 @@
 
 #include "abstractfile/indexercommon.h"
 
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KF5FileMetaData_FOUND
 
 #include <KFileMetaData/ExtractorCollection>
 #include <KFileMetaData/Extractor>
 #include <KFileMetaData/SimpleExtractionResult>
 #include <KFileMetaData/UserMetaData>
 #include <KFileMetaData/Properties>
-#include <KFileMetaData/EmbeddedImageData>
 
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KF5Baloo_FOUND
 
 #include <Baloo/File>
 
@@ -36,17 +35,21 @@
 class FileScannerPrivate
 {
 public:
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KF5FileMetaData_FOUND
     KFileMetaData::ExtractorCollection mAllExtractors;
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    KFileMetaData::PropertyMultiMap mAllProperties;
+#else
     KFileMetaData::PropertyMap mAllProperties;
+#endif
 
     KFileMetaData::EmbeddedImageData mImageScanner;
 #endif
 
     QMimeDatabase mMimeDb;
 
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KF5FileMetaData_FOUND
     const QHash<KFileMetaData::Property::Property, DataTypes::ColumnsRoles> propertyTranslation = {
         {KFileMetaData::Property::Artist, DataTypes::ColumnsRoles::ArtistRole},
         {KFileMetaData::Property::AlbumArtist, DataTypes::ColumnsRoles::AlbumArtistRole},
@@ -69,16 +72,18 @@ public:
 #endif
 
     const QStringList constSearchStrings = {
-        QStringLiteral("*[Cc]over*.jpg"),
-        QStringLiteral("*[Cc]over*.png"),
-        QStringLiteral("*[Ff]older*.jpg"),
-        QStringLiteral("*[Ff]older*.png"),
-        QStringLiteral("*[Ff]ront*.jpg"),
-        QStringLiteral("*[Ff]ront*.png"),
-        QStringLiteral("*[Aa]lbumart*.jpg"),
-        QStringLiteral("*[Aa]lbumart*.png"),
-        QStringLiteral("*[Cc]over*.jpg"),
-        QStringLiteral("*[Cc]over*.png")
+        QStringLiteral("*[Cc]over*.jpg")
+        ,QStringLiteral("*[Cc]over*.jpeg")
+        ,QStringLiteral("*[Cc]over*.png")
+        ,QStringLiteral("*[Ff]older*.jpg")
+        ,QStringLiteral("*[Ff]older*.jpeg")
+        ,QStringLiteral("*[Ff]older*.png")
+        ,QStringLiteral("*[Ff]ront*.jpg")
+        ,QStringLiteral("*[Ff]ront*.jpeg")
+        ,QStringLiteral("*[Ff]ront*.png")
+        ,QStringLiteral("*[Aa]lbumart*.jpg")
+        ,QStringLiteral("*[Aa]lbumart*.jpeg")
+        ,QStringLiteral("*[Aa]lbumart*.png")
     };
 };
 
@@ -109,7 +114,7 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile, const QF
     newTrack[DataTypes::RatingRole] = 0;
     newTrack[DataTypes::ElementTypeRole] = ElisaUtils::Track;
 
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KF5FileMetaData_FOUND
     const auto &fileMimeType = d->mMimeDb.mimeTypeForFile(localFileName);
     if (!fileMimeType.name().startsWith(QLatin1String("audio/"))) {
         return newTrack;
@@ -120,6 +125,17 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile, const QF
     const QList<KFileMetaData::Extractor*> &exList = d->mAllExtractors.fetchExtractors(mimetype);
 
     if (exList.isEmpty()) {
+        // when no extractors exist and we have an audio file, we fallback to filling the minimal
+        // set of properties to let Elisa be able to recognise and play the file.
+
+        qCDebug(orgKdeElisaIndexer()) << "FileScanner::shouldScanFile" << scanFile << localFileName << "no extractors" << fileMimeType;
+
+        newTrack[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
+        newTrack[DataTypes::ResourceRole] = scanFile;
+        newTrack[DataTypes::RatingRole] = 0;
+        newTrack[DataTypes::DurationRole] = QTime::fromMSecsSinceStartOfDay(1);
+        newTrack[DataTypes::ElementTypeRole] = ElisaUtils::Track;
+
         return newTrack;
     }
 
@@ -157,7 +173,7 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
 DataTypes::TrackDataType FileScanner::scanOneBalooFile(const QUrl &scanFile, const QFileInfo &scanFileInfo)
 {
     DataTypes::TrackDataType newTrack;
-#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+#if KF5Baloo_FOUND
     const auto &localFileName = scanFile.toLocalFile();
 
     newTrack[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
@@ -184,7 +200,7 @@ DataTypes::TrackDataType FileScanner::scanOneBalooFile(const QUrl &scanFile, con
 
 void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackDataType &trackData)
 {
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KF5FileMetaData_FOUND
     if (d->mAllProperties.isEmpty()) {
         return;
     }
@@ -207,11 +223,13 @@ void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackD
         } else {
             value = (*rangeBegin).second;
         }
-        const auto &translatedKey = d->propertyTranslation.find(key);
-        if (translatedKey.value() == DataTypes::DurationRole) {
-            trackData.insert(translatedKey.value(), QTime::fromMSecsSinceStartOfDay(int(1000 * (*rangeBegin).second.toDouble())));
-        } else if (translatedKey != d->propertyTranslation.end()) {
-            trackData.insert(translatedKey.value(), (*rangeBegin).second);
+        if (d->propertyTranslation.contains(key)) {
+            const auto &translatedKey = d->propertyTranslation.find(key);
+            if (translatedKey.value() == DataTypes::DurationRole) {
+                trackData.insert(translatedKey.value(), QTime::fromMSecsSinceStartOfDay(int(1000 * (*rangeBegin).second.toDouble())));
+            } else if (translatedKey != d->propertyTranslation.end()) {
+                trackData.insert(translatedKey.value(), (*rangeBegin).second);
+            }
         }
         rangeBegin = rangeEnd;
     }
@@ -220,7 +238,12 @@ void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackD
         return;
     }
 
-    trackData[DataTypes::HasEmbeddedCover] = checkEmbeddedCoverImage(localFileName);
+    if (checkEmbeddedCoverImage(localFileName)) {
+        trackData[DataTypes::HasEmbeddedCover] = true;
+        trackData[DataTypes::ImageUrlRole] = QUrl(QLatin1String("image://cover/") + localFileName);
+    } else {
+        trackData[DataTypes::HasEmbeddedCover] = false;
+    }
 
 #if !defined Q_OS_ANDROID && !defined Q_OS_WIN
     const auto fileData = KFileMetaData::UserMetaData(localFileName);
@@ -268,14 +291,18 @@ QUrl FileScanner::searchForCoverFile(const QString &localFileName)
 
 bool FileScanner::checkEmbeddedCoverImage(const QString &localFileName)
 {
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
-    const auto &imageData = d->mImageScanner.imageData(localFileName);
+#if KF5FileMetaData_FOUND
+    const auto &mimeType = QMimeDatabase().mimeTypeForFile(localFileName).name();
+    auto extractors = d->mAllExtractors.fetchExtractors(mimeType);
 
-    if (imageData.contains(KFileMetaData::EmbeddedImageData::FrontCover)) {
-        if (!imageData[KFileMetaData::EmbeddedImageData::FrontCover].isEmpty()) {
+    for (const auto &extractor : extractors) {
+        KFileMetaData::SimpleExtractionResult result(localFileName, mimeType, KFileMetaData::ExtractionResult::ExtractImageData);
+        extractor->extract(&result);
+        if (!result.imageData().isEmpty()) {
             return true;
         }
     }
+
 #else
     Q_UNUSED(localFileName)
 #endif
