@@ -59,7 +59,7 @@ void ElisaConfigurationDialog::setRootPath(const QStringList &rootPath)
 
     if (mRootPath.isEmpty()) {
         auto systemMusicPaths = QStandardPaths::standardLocations(QStandardPaths::MusicLocation);
-        for (const auto &musicPath : qAsConst(systemMusicPaths)) {
+        for (const auto &musicPath : std::as_const(systemMusicPaths)) {
             mRootPath.push_back(musicPath);
         }
     }
@@ -72,11 +72,15 @@ void ElisaConfigurationDialog::setRootPath(const QStringList &rootPath)
 void ElisaConfigurationDialog::save()
 {
     Elisa::ElisaConfiguration::setRootPath(mRootPath);
+    Elisa::ElisaConfiguration::setShowNowPlayingBackground(mShowNowPlayingBackground);
     Elisa::ElisaConfiguration::setShowProgressOnTaskBar(mShowProgressInTaskBar);
     Elisa::ElisaConfiguration::setShowSystemTrayIcon(mShowSystemTrayIcon);
-    Elisa::ElisaConfiguration::setForceUsageOfFastFileSearch(mForceUsageOfFastFileSearch);
+    Elisa::ElisaConfiguration::setForceUsageOfFastFileSearch(!mForceUsageOfSlowFileSystemIndexing);
+    Elisa::ElisaConfiguration::setAlwaysUseAbsolutePlaylistPaths(mAlwaysUseAbsolutePlaylistPaths);
     Elisa::ElisaConfiguration::setPlayAtStartup(mPlayAtStartup);
+    Elisa::ElisaConfiguration::setScanAtStartup(mScanAtStartup);
     Elisa::ElisaConfiguration::setColorScheme(mColorScheme);
+    Elisa::ElisaConfiguration::setUseFavoriteStyleRatings(mUseFavoriteStyleRatings);
 
     Elisa::ElisaConfiguration::setEmbeddedView(Elisa::ElisaConfiguration::EnumEmbeddedView::NoView);
     switch (mEmbeddedView)
@@ -120,6 +124,18 @@ void ElisaConfigurationDialog::cancel()
     }
 }
 
+void ElisaConfigurationDialog::setShowNowPlayingBackground(bool showNowPlayingBackground)
+{
+    if (mShowNowPlayingBackground == showNowPlayingBackground) {
+        return;
+    }
+
+    mShowNowPlayingBackground = showNowPlayingBackground;
+    Q_EMIT showNowPlayingBackgroundChanged();
+
+    setDirty();
+}
+
 void ElisaConfigurationDialog::setShowProgressInTaskBar(bool showProgressInTaskBar)
 {
     if (mShowProgressInTaskBar == showProgressInTaskBar) {
@@ -144,14 +160,26 @@ void ElisaConfigurationDialog::setShowSystemTrayIcon(bool showSystemTrayIcon)
     setDirty();
 }
 
-void ElisaConfigurationDialog::setForceUsageOfFastFileSearch(bool forceUsageOfFastFileSearch)
+void ElisaConfigurationDialog::setForceUsageOfSlowFileSystemIndexing(bool forceUsageOfSlowFileSystemIndexing)
 {
-    if (mForceUsageOfFastFileSearch == forceUsageOfFastFileSearch) {
+    if (mForceUsageOfSlowFileSystemIndexing == forceUsageOfSlowFileSystemIndexing) {
         return;
     }
 
-    mForceUsageOfFastFileSearch = forceUsageOfFastFileSearch;
-    Q_EMIT forceUsageOfFastFileSearchChanged();
+    mForceUsageOfSlowFileSystemIndexing = forceUsageOfSlowFileSystemIndexing;
+    Q_EMIT forceUsageOfSlowFileSystemIndexingChanged();
+
+    setDirty();
+}
+
+void ElisaConfigurationDialog::setAlwaysUseAbsolutePlaylistPaths(bool alwaysUseAbsolutePlaylistPaths)
+{
+    if (mAlwaysUseAbsolutePlaylistPaths == alwaysUseAbsolutePlaylistPaths) {
+        return;
+    }
+
+    mAlwaysUseAbsolutePlaylistPaths = alwaysUseAbsolutePlaylistPaths;
+    Q_EMIT alwaysUseAbsolutePlaylistPathsChanged();
 
     setDirty();
 }
@@ -191,6 +219,17 @@ void ElisaConfigurationDialog::setPlayAtStartup(bool playAtStartup)
     setDirty();
 }
 
+void ElisaConfigurationDialog::setScanAtStartup(bool scanAtStartup)
+{
+    if (mScanAtStartup == scanAtStartup) {
+        return;
+    }
+    mScanAtStartup = scanAtStartup;
+    Q_EMIT scanAtStartupChanged();
+
+    setDirty();
+}
+
 void ElisaConfigurationDialog::setColorScheme(const QString &scheme)
 {
     if (mColorScheme == scheme) {
@@ -202,11 +241,31 @@ void ElisaConfigurationDialog::setColorScheme(const QString &scheme)
     setDirty();
 }
 
+void ElisaConfigurationDialog::setUseFavoriteStyleRatings(bool useFavoriteStyleRatings)
+{
+    if (mUseFavoriteStyleRatings == useFavoriteStyleRatings) {
+        return;
+    }
+    mUseFavoriteStyleRatings = useFavoriteStyleRatings;
+    Q_EMIT useFavoriteStyleRatingsChanged();
+
+    setDirty();
+}
+
+void ElisaConfigurationDialog::removeMusicLocation(QString location)
+{
+    mRootPath.removeAll(location);
+    Q_EMIT rootPathChanged(mRootPath);
+}
+
 void ElisaConfigurationDialog::configChanged()
 {
     mRootPath = Elisa::ElisaConfiguration::rootPath();
     Q_EMIT rootPathChanged(mRootPath);
 
+    mShowNowPlayingBackground = Elisa::ElisaConfiguration::showNowPlayingBackground();
+    Q_EMIT showNowPlayingBackgroundChanged();
+
     mShowProgressInTaskBar = Elisa::ElisaConfiguration::showProgressOnTaskBar();
     Q_EMIT showProgressInTaskBarChanged();
 
@@ -216,11 +275,20 @@ void ElisaConfigurationDialog::configChanged()
     mPlayAtStartup = Elisa::ElisaConfiguration::playAtStartup();
     Q_EMIT playAtStartupChanged();
 
+    mScanAtStartup = Elisa::ElisaConfiguration::scanAtStartup();
+    Q_EMIT scanAtStartupChanged();
+
     mColorScheme = Elisa::ElisaConfiguration::colorScheme();
     Q_EMIT colorSchemeChanged();
 
-    mForceUsageOfFastFileSearch = Elisa::ElisaConfiguration::forceUsageOfFastFileSearch();
-    Q_EMIT forceUsageOfFastFileSearchChanged();
+    mUseFavoriteStyleRatings = Elisa::ElisaConfiguration::useFavoriteStyleRatings();
+    Q_EMIT useFavoriteStyleRatingsChanged();
+
+    mForceUsageOfSlowFileSystemIndexing = !Elisa::ElisaConfiguration::forceUsageOfFastFileSearch();
+    Q_EMIT forceUsageOfSlowFileSystemIndexingChanged();
+
+    mAlwaysUseAbsolutePlaylistPaths = Elisa::ElisaConfiguration::alwaysUseAbsolutePlaylistPaths();
+    Q_EMIT alwaysUseAbsolutePlaylistPathsChanged();
 
     switch (Elisa::ElisaConfiguration::embeddedView())
     {
