@@ -7,17 +7,13 @@
 #include "mediaplaylist.h"
 
 #include "playListLogging.h"
-#include "datatypes.h"
 
 #include <QUrl>
-#include <QPersistentModelIndex>
 #include <QList>
-#include <QMediaPlaylist>
 #include <QFileInfo>
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QDebug>
-#include <QRandomGenerator>
 
 #include <algorithm>
 
