@@ -9,9 +9,9 @@
 #include "mediaplaylistproxymodel.h"
 #include "mediaplaylist.h"
 #include "playListLogging.h"
+#include "elisa_settings.h"
 #include <QItemSelection>
 #include <QList>
-#include <QMediaPlaylist>
 #include <QRandomGenerator>
 #include <QFile>
 #include <QFileInfo>
@@ -34,8 +34,6 @@ public:
 
     QPersistentModelIndex mNextTrack;
 
-    QMediaPlaylist mLoadPlaylist;
-
     QList<int> mRandomMapping;
 
     QVariantMap mPersistentSettingsForUndo;
@@ -57,8 +55,6 @@ public:
 MediaPlayListProxyModel::MediaPlayListProxyModel(QObject *parent) : QAbstractProxyModel (parent),
     d(std::make_unique<MediaPlayListProxyModelPrivate>())
 {
-    connect(&d->mLoadPlaylist, &QMediaPlaylist::loaded, this, &MediaPlayListProxyModel::loadPlayListLoaded);
-    connect(&d->mLoadPlaylist, &QMediaPlaylist::loadFailed, this, &MediaPlayListProxyModel::loadPlayListLoadFailed);
     d->mRandomGenerator.seed(static_cast<unsigned int>(QTime::currentTime().msec()));
 }
 
@@ -156,7 +152,7 @@ QModelIndex MediaPlayListProxyModel::parent(const QModelIndex &child) const
 
 bool MediaPlayListProxyModel::hasChildren(const QModelIndex &parent) const
 {
-    return (!parent.isValid()) ? false : (rowCount() > 0);
+    return (parent.isValid()) ? false : (rowCount() > 0);
 }
 
 void MediaPlayListProxyModel::setPlayListModel(MediaPlayList *playListModel)
@@ -252,8 +248,15 @@ void MediaPlayListProxyModel::setShufflePlayList(const bool value)
 
                 QModelIndexList from;
                 from.reserve(playListSize);
+                // Adding the current track first if it is not the only one
+                if (playListSize > 1) {
+                    if (currentTrackRow() != 0) {
+                        std::swap(d->mRandomMapping[0], d->mRandomMapping[currentTrackRow()]);
+                    }
+                    from.append(index(d->mRandomMapping.at(0), 0));
+                }
                 // Fisher-Yates algorithm
-                for (int i = 0;  i < playListSize - 1; ++i) {
+                for (int i = 1;  i < playListSize - 1; ++i) {
                     const int swapIndex = d->mRandomGenerator.bounded(i, playListSize);
                     std::swap(d->mRandomMapping[i], d->mRandomMapping[swapIndex]);
                     from.append(index(d->mRandomMapping.at(i), 0));
@@ -309,7 +312,7 @@ void MediaPlayListProxyModel::sourceRowsInserted(const QModelIndex &parent, int
     if (d->mShufflePlayList) {
         const auto newItemsCount = end - start + 1;
         d->mRandomMapping.reserve(rowCount() + newItemsCount);
-        if (rowCount() == 0 || newItemsCount == 1) {
+        if (rowCount() == 0) {
             beginInsertRows(parent, start, end);
             for (int i = 0; i < newItemsCount; ++i) {
                 //QRandomGenerator.bounded(int) is exclusive, thus + 1
@@ -497,9 +500,7 @@ void MediaPlayListProxyModel::enqueue(const DataTypes::EntryDataList &newEntries
     d->mTriggerPlay = triggerPlay;
 
     if (enqueueMode == ElisaUtils::ReplacePlayList) {
-        if (rowCount() == 0) {
-            Q_EMIT hideUndoNotification();
-        } else {
+        if (rowCount() != 0) {
             clearPlayList();
         }
     }
@@ -685,13 +686,12 @@ void MediaPlayListProxyModel::undoClearPlayList()
     d->mPlayListModel->clearPlayList();
 
     setPersistentState(d->mPersistentSettingsForUndo);
-    Q_EMIT hideUndoNotification();
     Q_EMIT undoClearPlayListPlayer();
 }
 
 void MediaPlayListProxyModel::determineTracks()
 {
-    if (!d->mCurrentTrack.isValid()) {
+    if (!d->mCurrentTrack.isValid() || d->mCurrentPlayListPosition != d->mCurrentTrack.row()) {
         for (int row = 0; row < rowCount(); ++row) {
             auto candidateTrack = index(row, 0);
             const auto type = candidateTrack.data(MediaPlayList::ElementTypeRole).value<ElisaUtils::PlayListEntryType>();
@@ -714,53 +714,63 @@ void MediaPlayListProxyModel::determineTracks()
 
 bool MediaPlayListProxyModel::savePlayList(const QUrl &fileName)
 {
-    QMediaPlaylist savePlaylist;
+    QFile outputFile(fileName.toLocalFile());
+    auto open = outputFile.open(QFile::WriteOnly);
+    if (!open) {
+        return false;
+    }
 
-    for (int i = 0; i < rowCount(); ++i) {
-        if (data(index(i,0), MediaPlayList::IsValidRole).toBool()) {
-            data(index(i,0), MediaPlayList::ResourceRole).toUrl();
-            savePlaylist.addMedia(data(index(i,0), MediaPlayList::ResourceRole).toUrl());
+    if (Elisa::ElisaConfiguration::self()->alwaysUseAbsolutePlaylistPaths()) {
+        for (int i = 0; i < rowCount(); ++i) {
+            if (data(index(i,0), MediaPlayList::IsValidRole).toBool()) {
+                data(index(i,0), MediaPlayList::ResourceRole).toUrl();
+                outputFile.write(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile().toUtf8());
+                outputFile.write("\n");
+            }
+        }
+    } else {
+        QFileInfo playlistFile(fileName.toLocalFile());
+        QDir dir(playlistFile.absolutePath());
+
+        for (int i = 0; i < rowCount(); ++i) {
+            if (data(index(i,0), MediaPlayList::IsValidRole).toBool()) {
+                QFileInfo musicFile(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
+
+                if (musicFile.dir().path() == dir.absolutePath()) {
+                    outputFile.write(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile().toUtf8());
+                } else {
+                    outputFile.write(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile().toUtf8());
+                }
+                outputFile.write("\n");
+            }
         }
     }
 
-    return savePlaylist.save(fileName, "m3u8");
+    return true;
 }
 
 void MediaPlayListProxyModel::loadPlayList(const QUrl &fileName)
 {
-    d->mLoadPlaylist.clear();
-    d->mLoadPlaylist.load(fileName, "m3u8");
-}
-
-void MediaPlayListProxyModel::loadPlayListLoaded()
-{
+    QFile inputFile(fileName.toLocalFile());
+    auto open = inputFile.open(QFile::ReadOnly);
+    if (!open) {
+        Q_EMIT playListLoadFailed();
+    }
+    const auto data = inputFile.readAll();
     clearPlayList();
-
     auto newTracks = DataTypes::EntryDataList{};
-    for (int i = 0; i < d->mLoadPlaylist.mediaCount(); ++i) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    for (const auto &l : data.split('\n')) {
+        const auto &line = QString::fromUtf8(l);
+        const auto &url = line.startsWith(QStringLiteral("file:/")) ? QUrl(line) : QUrl::fromLocalFile(line);
         newTracks.push_back({{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
-                               {DataTypes::ResourceRole, d->mLoadPlaylist.media(i).request().url()}}}, {}, {}});
-#else
-        newTracks.push_back({{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
-                               {DataTypes::ResourceRole, d->mLoadPlaylist.media(i).canonicalUrl()}}}, {}, {}});
-#endif
+            {DataTypes::ResourceRole, url}}}, {}, {}});
     }
-
     enqueue(newTracks, ElisaUtils::ReplacePlayList, ElisaUtils::DoNotTriggerPlay);
 
     Q_EMIT persistentStateChanged();
-
-    d->mLoadPlaylist.clear();
     Q_EMIT playListLoaded();
 }
 
-void MediaPlayListProxyModel::loadPlayListLoadFailed()
-{
-    d->mLoadPlaylist.clear();
-    Q_EMIT playListLoadFailed();
-}
-
 QVariantMap MediaPlayListProxyModel::persistentState() const
 {
     QVariantMap currentState;
@@ -816,9 +826,7 @@ void MediaPlayListProxyModel::enqueueDirectory(const QUrl &fileName, ElisaUtils:
     if (!fileName.isLocalFile()) return;
     // clear playlist if required
     if (enqueueMode == ElisaUtils::ReplacePlayList) {
-        if (rowCount() == 0) {
-            Q_EMIT hideUndoNotification();
-        } else {
+        if (rowCount() != 0) {
             clearPlayList();
         }
     }
