@@ -1,18 +1,7 @@
 /*
- * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2015 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "datamodel.h"
@@ -20,11 +9,7 @@
 #include "modeldataloader.h"
 #include "musiclistenersmanager.h"
 
-#include <QUrl>
-#include <QTimer>
-#include <QPointer>
-#include <QVector>
-#include <QDebug>
+#include "models/modelLogging.h"
 
 #include <algorithm>
 
@@ -91,6 +76,7 @@ QHash<int, QByteArray> DataModel::roleNames() const
     roles[static_cast<int>(DataTypes::ColumnsRoles::TitleRole)] = "title";
     roles[static_cast<int>(DataTypes::ColumnsRoles::SecondaryTextRole)] = "secondaryText";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ImageUrlRole)] = "imageUrl";
+    roles[static_cast<int>(DataTypes::ColumnsRoles::MultipleImageUrlsRole)] = "multipleImageUrls";
     roles[static_cast<int>(DataTypes::ColumnsRoles::DatabaseIdRole)] = "databaseId";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ElementTypeRole)] = "dataType";
     roles[static_cast<int>(DataTypes::ColumnsRoles::ResourceRole)] = "url";
@@ -102,12 +88,14 @@ QHash<int, QByteArray> DataModel::roleNames() const
 
     roles[static_cast<int>(DataTypes::ColumnsRoles::AlbumRole)] = "album";
     roles[static_cast<int>(DataTypes::ColumnsRoles::AlbumArtistRole)] = "albumArtist";
-    roles[static_cast<int>(DataTypes::ColumnsRoles::DurationRole)] = "duration";
+    roles[static_cast<int>(DataTypes::ColumnsRoles::StringDurationRole)] = "duration";
     roles[static_cast<int>(DataTypes::ColumnsRoles::TrackNumberRole)] = "trackNumber";
     roles[static_cast<int>(DataTypes::ColumnsRoles::DiscNumberRole)] = "discNumber";
     roles[static_cast<int>(DataTypes::ColumnsRoles::RatingRole)] = "rating";
+    roles[static_cast<int>(DataTypes::ColumnsRoles::YearRole)] = "year";
     roles[static_cast<int>(DataTypes::ColumnsRoles::IsSingleDiscAlbumRole)] = "isSingleDiscAlbum";
     roles[static_cast<int>(DataTypes::ColumnsRoles::FullDataRole)] = "fullData";
+    roles[static_cast<int>(DataTypes::ColumnsRoles::HasChildrenRole)] = "hasChildren";
 
     return roles;
 }
@@ -164,11 +152,12 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
         break;
-    case DataTypes::ColumnsRoles::DurationRole:
+    case DataTypes::ColumnsRoles::StringDurationRole:
     {
         switch (d->mModelType)
         {
@@ -189,6 +178,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
         case ElisaUtils::Radio:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -212,6 +202,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -246,6 +237,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -255,23 +247,24 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         switch (d->mModelType)
         {
         case ElisaUtils::Track:
-            result = QVariant::fromValue(d->mAllTrackData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllTrackData[index.row()]));
             break;
         case ElisaUtils::Radio:
-            result = QVariant::fromValue(d->mAllRadiosData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllRadiosData[index.row()]));
             break;
         case ElisaUtils::Album:
-            result = QVariant::fromValue(d->mAllAlbumData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllAlbumData[index.row()]));
             break;
         case ElisaUtils::Artist:
-            result = QVariant::fromValue(d->mAllArtistData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllArtistData[index.row()]));
             break;
         case ElisaUtils::Genre:
-            result = QVariant::fromValue(d->mAllGenreData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllGenreData[index.row()]));
             break;
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -292,12 +285,34 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Genre:
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             result = QUrl{};
             break;
         }
         break;
     }
+    case DataTypes::ColumnsRoles::HasChildrenRole:
+    {
+        switch (d->mModelType)
+        {
+        case ElisaUtils::Track:
+        case ElisaUtils::FileName:
+        case ElisaUtils::Radio:
+        case ElisaUtils::Unknown:
+            result = false;
+            break;
+        case ElisaUtils::Album:
+        case ElisaUtils::Artist:
+        case ElisaUtils::Genre:
+        case ElisaUtils::Lyricist:
+        case ElisaUtils::Composer:
+        case ElisaUtils::Container:
+            result = true;
+            break;
+        }
+        break;
+    }
     default:
         switch(d->mModelType)
         {
@@ -319,6 +334,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -368,13 +384,15 @@ bool DataModel::isBusy() const
     return d->mIsBusy;
 }
 
-void DataModel::initialize(MusicListenersManager *manager, DatabaseInterface *database,
-                           ElisaUtils::PlayListEntryType modelType, ElisaUtils::FilterType filter,
-                           const QString &genre, const QString &artist, qulonglong databaseId)
+void DataModel::initializeByData(MusicListenersManager *manager, DatabaseInterface *database,
+                                 ElisaUtils::PlayListEntryType modelType, ElisaUtils::FilterType filter,
+                                 const DataTypes::DataType &dataFilter)
 {
-    d->mDatabaseId = databaseId;
-    d->mGenre = genre;
-    d->mArtist = artist;
+    qCDebug(orgKdeElisaModel()) << "DataModel::initialize" << modelType << filter << dataFilter;
+
+    d->mDatabaseId = dataFilter[DataTypes::DatabaseIdRole].toULongLong();
+    d->mGenre = dataFilter[DataTypes::GenreRole].toString();
+    d->mArtist = dataFilter[DataTypes::ArtistRole].toString();
 
     initializeModel(manager, database, modelType, filter);
 }
@@ -437,6 +455,7 @@ void DataModel::initializeModel(MusicListenersManager *manager, DatabaseInterfac
         connect(this, &DataModel::needFrequentlyPlayedData,
                 d->mDataLoader, &ModelDataLoader::loadFrequentlyPlayedData);
         break;
+    case ElisaUtils::FilterByPath:
     case ElisaUtils::UnknownFilter:
         break;
     }
@@ -471,6 +490,7 @@ void DataModel::askModelData()
     case ElisaUtils::FilterByFrequentlyPlayed:
         Q_EMIT needFrequentlyPlayedData(d->mModelType);
         break;
+    case ElisaUtils::FilterByPath:
     case ElisaUtils::UnknownFilter:
         break;
     }
@@ -921,6 +941,22 @@ void DataModel::albumModified(const DataModel::AlbumDataType &modifiedAlbum)
     Q_EMIT dataChanged(index(albumIndex, 0), index(albumIndex, 0));
 }
 
+void DataModel::initialize(MusicListenersManager *manager, DatabaseInterface *database,
+                           ElisaUtils::PlayListEntryType modelType, ElisaUtils::FilterType filter,
+                           const QString &genre, const QString &artist, qulonglong databaseId,
+                           const QUrl &pathFilter)
+{
+    Q_UNUSED(pathFilter)
+
+    qCDebug(orgKdeElisaModel()) << "DataModel::initialize" << modelType << filter << databaseId << genre << artist;
+
+    d->mDatabaseId = databaseId;
+    d->mGenre = genre;
+    d->mArtist = artist;
+
+    initializeModel(manager, database, modelType, filter);
+}
+
 void DataModel::cleanedDatabase()
 {
     beginResetModel();
