@@ -8,19 +8,18 @@
 
 #include "viewslistdata.h"
 #include "viewconfigurationdata.h"
-#include "datatypes.h"
 #include "viewsLogging.h"
 #include "models/datamodel.h"
 #include "models/gridviewproxymodel.h"
 
-#if defined KF5KIO_FOUND && KF5KIO_FOUND
+#if KF5KIO_FOUND
 #include "models/filebrowsermodel.h"
 #include "models/filebrowserproxymodel.h"
 #endif
 
 #include "elisa_settings.h"
 
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #include <QQmlEngine>
 #include <QMetaEnum>
@@ -39,9 +38,9 @@ public:
                              ElisaUtils::Track,
                              Qt::DisplayRole,
                              {Qt::DisplayRole},
-                             {i18n("Title")},
+                             {i18nc("@title:inmenu", "Title")},
                              Qt::AscendingOrder,
-                             {i18n("A-Z"), i18n("Z-A")},
+                             {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              ViewManager::SingleAlbum,
                              ViewManager::DiscHeaders,
                              ViewManager::IsTrack,
@@ -54,9 +53,9 @@ public:
                              ElisaUtils::Artist,
                              Qt::DisplayRole,
                              {Qt::DisplayRole},
-                             {i18n("Name")},
+                             {i18nc("@title:inmenu", "Name")},
                              Qt::AscendingOrder,
-                             {i18n("A-Z"), i18n("Z-A")},
+                             {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              QUrl{QStringLiteral("image://icon/view-media-artist")},
                              ViewManager::DelegateWithoutSecondaryText,
                              ViewManager::ViewHideRating,
@@ -69,10 +68,10 @@ public:
                               ElisaUtils::Album,
                               DataTypes::TitleRole,
                               {DataTypes::TitleRole, DataTypes::GenreRole, DataTypes::YearRole},
-                              {i18n("Title"), i18n("Genre"), i18n("Year")},
+                              {i18nc("@title:inmenu", "Title"), i18nc("@title:inmenu", "Genre"), i18nc("@title:inmenu", "Year")},
                               Qt::AscendingOrder,
-                              {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
-                              QUrl{QStringLiteral("image://icon/media-optical-audio")},
+                              {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
+                              QUrl{QStringLiteral("image://icon/media-default-album")},
                               ViewManager::DelegateWithSecondaryText,
                               ViewManager::ViewShowRating,
                               ViewManager::IsFlatModel}},
@@ -84,9 +83,9 @@ public:
                                  ElisaUtils::FileName,
                                  Qt::DisplayRole,
                                  {Qt::DisplayRole},
-                                 {i18n("Name")},
+                                 {i18nc("@title:inmenu", "Name")},
                                  Qt::AscendingOrder,
-                                 {i18n("A-Z"), i18n("Z-A")},
+                                 {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                  QUrl{QStringLiteral("image://icon/folder")},
                                  ViewManager::DelegateWithoutSecondaryText,
                                  ViewManager::ViewHideRating,
@@ -290,7 +289,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
     {
     case FileBrowserModel:
     {
-#if defined KF5KIO_FOUND && KF5KIO_FOUND
+#if KF5KIO_FOUND
         newModel = new ::FileBrowserModel;
         auto *realProxyModel = new FileBrowserProxyModel;
         proxyModel = realProxyModel;
@@ -331,9 +330,9 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                                                          viewParamaters.mMainImage, viewParamaters.mDataType,
                                                                          newModel, proxyModel, viewParamaters.mFallbackItemIcon,
                                                                          viewParamaters.mDataFilter,
-                                                                         computePreferredSortRole(viewParamaters.mSortRole),
+                                                                         computePreferredSortRole(viewParamaters.mSortRole, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortRoles, viewParamaters.mSortRoleNames,
-                                                                         computePreferredSortOrder(viewParamaters.mSortOrder),
+                                                                         computePreferredSortOrder(viewParamaters.mSortOrder, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortOrderNames,
                                                                          viewParamaters.mViewCanBeRated, viewParamaters.mShowSecondaryTextOnDelegates,
                                                                          viewParamaters.mIsTreeModel);
@@ -358,9 +357,9 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                                                          viewParamaters.mMainTitle, viewParamaters.mSecondaryTitle,
                                                                          viewParamaters.mMainImage, viewParamaters.mDataType,
                                                                          newModel, proxyModel, viewParamaters.mDataFilter,
-                                                                         computePreferredSortRole(viewParamaters.mSortRole),
+                                                                         computePreferredSortRole(viewParamaters.mSortRole, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortRoles, viewParamaters.mSortRoleNames,
-                                                                         computePreferredSortOrder(viewParamaters.mSortOrder),
+                                                                         computePreferredSortOrder(viewParamaters.mSortOrder, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortOrderNames,
                                                                          viewParamaters.mAlbumCardinality, viewParamaters.mAlbumViewStyle,
                                                                          viewParamaters.mRadioSpecificStyle, viewParamaters.mIsTreeModel);
@@ -423,7 +422,11 @@ QStringList::iterator ViewManager::findViewPreference(QStringList &list, const Q
 {
     auto itViewPreference = list.end();
     for(itViewPreference = list.begin(); itViewPreference != list.end(); ++itViewPreference) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         auto parts = itViewPreference->splitRef(QStringLiteral("=="));
+#else
+        auto parts = QStringView(*itViewPreference).split(QStringLiteral("=="));
+#endif
         if (parts.size() != 2) {
             continue;
         }
@@ -435,14 +438,27 @@ QStringList::iterator ViewManager::findViewPreference(QStringList &list, const Q
     return itViewPreference;
 }
 
-Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue) const
+Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue, ElisaUtils::FilterType filterType) const
 {
+    switch (filterType)
+    {
+    case ElisaUtils::FilterByRecentlyPlayed:
+    case ElisaUtils::FilterByFrequentlyPlayed:
+        return Qt::DescendingOrder;
+    default:
+        break;
+    }
+
     auto currentSortOrderPreferences = Elisa::ElisaConfiguration::sortOrderPreferences();
     auto viewId = buildViewId();
     auto itViewPreference = findViewPreference(currentSortOrderPreferences, viewId);
 
     if (itViewPreference != currentSortOrderPreferences.end()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         auto result = itViewPreference->splitRef(QStringLiteral("=="));
+#else
+        auto result = QStringView(*itViewPreference).split(QStringLiteral("=="));
+#endif
         if (result.size() == 2) {
             const auto &sortOrderMetaEnum = QMetaEnum::fromType<Qt::SortOrder>();
             bool conversionOk;
@@ -456,14 +472,28 @@ Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue)
     return initialValue;
 }
 
-int ViewManager::computePreferredSortRole(int initialValue) const
+int ViewManager::computePreferredSortRole(int initialValue, ElisaUtils::FilterType filterType) const
 {
+    switch (filterType)
+    {
+    case ElisaUtils::FilterByRecentlyPlayed:
+        return DataTypes::LastPlayDate;
+    case ElisaUtils::FilterByFrequentlyPlayed:
+        return DataTypes::PlayFrequency;
+    default:
+        break;
+    }
+
     auto currentSortRolePreferences = Elisa::ElisaConfiguration::sortRolePreferences();
     auto viewId = buildViewId();
     auto itViewPreference = findViewPreference(currentSortRolePreferences, viewId);
 
     if (itViewPreference != currentSortRolePreferences.end()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         auto result = itViewPreference->splitRef(QStringLiteral("=="));
+#else
+        auto result = QStringView(*itViewPreference).split(QStringLiteral("=="));
+#endif
         if (result.size() == 2) {
             const auto &sortRoleMetaEnum = QMetaEnum::fromType<DataTypes::ColumnsRoles>();
             bool conversionOk;
