@@ -12,7 +12,7 @@
 
 #include "viewsLogging.h"
 
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #include <QUrl>
 #include <QDir>
@@ -20,10 +20,10 @@
 class ViewsListDataPrivate
 {
 public:
-    QList<ViewParameters> mViewsParameters = {{{i18nc("Title of the view of the playlist", "Now Playing")},
+    QList<ViewParameters> mViewsParameters = {{{i18nc("@title:window Title of the view of the playlist", "Now Playing")},
                                                QUrl{QStringLiteral("image://icon/view-media-lyrics")},
                                                ViewManager::ContextView},
-                                              {{i18nc("Title of the view of recently played tracks", "Recently Played")},
+                                              {{i18nc("@title:window Title of the view of recently played tracks", "Recently Played")},
                                                QUrl{QStringLiteral("image://icon/media-playlist-play")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
@@ -31,14 +31,14 @@ public:
                                                ElisaUtils::Track,
                                                DataTypes::LastPlayDate,
                                                {DataTypes::LastPlayDate},
-                                               {i18n("Last Played Date")},
+                                               {i18nc("@title:menu", "Last Played Date")},
                                                Qt::DescendingOrder,
-                                               {i18n("Least Recently Played First"), i18n("Most Recently Played First")},
+                                               {i18nc("@item:inmenu", "Least Recently Played First"), i18nc("@item:inmenu", "Most Recently Played First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsTrack,
                                                ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of frequently played tracks", "Frequently Played")},
+                                              {{i18nc("@title:window Title of the view of frequently played tracks", "Frequently Played")},
                                                QUrl{QStringLiteral("image://icon/view-media-playcount")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
@@ -46,14 +46,14 @@ public:
                                                ElisaUtils::Track,
                                                DataTypes::PlayFrequency,
                                                {DataTypes::PlayFrequency},
-                                               {i18n("Play Frequency")},
+                                               {i18nc("@title:menu", "Play Frequency")},
                                                Qt::DescendingOrder,
-                                               {i18n("Least Frequently Played First"), i18n("Most Frequently Played First")},
+                                               {i18nc("@item:inmenu", "Least Frequently Played First"), i18nc("@item:inmenu", "Most Frequently Played First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsTrack,
                                                ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all albums", "Albums")},
+                                              {{i18nc("@title:window Title of the view of all albums", "Albums")},
                                                QUrl{QStringLiteral("image://icon/view-media-album-cover")},
                                                ViewManager::GridView,
                                                ViewManager::GenericDataModel,
@@ -61,14 +61,14 @@ public:
                                                ElisaUtils::Album,
                                                DataTypes::TitleRole,
                                                {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
-                                               {i18n("Title"), i18n("Artist"), i18n("Genre"), i18n("Year")},
+                                               {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"), i18nc("@title:menu", "Year")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
-                                               QUrl{QStringLiteral("image://icon/media-optical-audio")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
+                                               QUrl{QStringLiteral("image://icon/media-default-album")},
                                                ViewManager::DelegateWithSecondaryText,
                                                ViewManager::ViewShowRating,
                                                ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all artists", "Artists")},
+                                              {{i18nc("@title:window Title of the view of all artists", "Artists")},
                                                QUrl{QStringLiteral("image://icon/view-media-artist")},
                                                ViewManager::GridView,
                                                ViewManager::GenericDataModel,
@@ -76,14 +76,14 @@ public:
                                                ElisaUtils::Artist,
                                                Qt::DisplayRole,
                                                {Qt::DisplayRole},
-                                               {i18n("Name")},
+                                               {i18nc("@title:menu", "Name")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                                QUrl{QStringLiteral("image://icon/view-media-artist")},
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
                                                ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all tracks", "Tracks")},
+                                              {{i18nc("@title:window Title of the view of all tracks", "Tracks")},
                                                QUrl{QStringLiteral("image://icon/view-media-track")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
@@ -92,17 +92,20 @@ public:
                                                DataTypes::TitleRole,
                                                {DataTypes::TitleRole, DataTypes::AlbumRole, DataTypes::ArtistRole,
                                                 DataTypes::GenreRole, DataTypes::YearRole, DataTypes::DurationRole,
-                                                DataTypes::ComposerRole, DataTypes::LyricistRole},
-                                               {i18n("Title"), i18n("Album"), i18n("Artist"), i18n("Genre"),
-                                                i18n("Year"), i18n("Duration"), i18n("Composer"), i18n("Lyricist")},
+                                                DataTypes::ComposerRole, DataTypes::LyricistRole,
+                                                DataTypes::FileModificationTime},
+                                               {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Album"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"),
+                                                i18nc("@title:menu", "Year"), i18nc("@title:menu", "Duration"), i18nc("@title:menu", "Composer"), i18nc("@title:menu", "Lyricist"),
+                                                i18nc("@title:menu", "Last Modified")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"),
-                                                i18n("Oldest First"), i18n("Newest First"), i18n("Shortest First"), i18n("Longest First"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"),
+                                                i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First"), i18nc("@item:inmenu", "Shortest First"), i18nc("@item:inmenu", "Longest First"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"),
+                                                i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsTrack,
                                                ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all genres", "Genres")},
+                                              {{i18nc("@title:window Title of the view of all genres", "Genres")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::GridView,
                                                ViewManager::GenericDataModel,
@@ -110,14 +113,14 @@ public:
                                                ElisaUtils::Genre,
                                                Qt::DisplayRole,
                                                {Qt::DisplayRole},
-                                               {i18n("Genre")},
+                                               {i18nc("@title:menu", "Genre")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
                                                ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the file browser view", "Files")},
+                                              {{i18nc("@title:window Title of the file browser view", "Files")},
                                                QUrl{QStringLiteral("image://icon/document-open-folder")},
                                                ViewManager::GridView,
                                                ViewManager::FileBrowserModel,
@@ -127,9 +130,9 @@ public:
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
                                                ViewManager::IsFlatModel,
-                                               QUrl::fromLocalFile(QDir::homePath())
+                                               QUrl::fromLocalFile(QDir::rootPath())
                                               },
-                                              {{i18nc("Title of the file radios browser view", "Radio Stations")},
+                                              {{i18nc("@title:window Title of the file radios browser view", "Radio Stations")},
                                                QUrl{QStringLiteral("image://icon/radio")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
@@ -137,9 +140,9 @@ public:
                                                ElisaUtils::Radio,
                                                Qt::DisplayRole,
                                                {Qt::DisplayRole},
-                                               {i18n("Name")},
+                                               {i18nc("@title:menu", "Name")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsRadio,
@@ -319,14 +322,14 @@ void ViewsListData::artistsAdded(const DataTypes::ListArtistDataType &newData)
     Q_EMIT dataAboutToBeAdded(d->mViewsParameters.size(), d->mViewsParameters.size() + newData.size() - 1);
     for (const auto &oneArtist : newData) {
         d->mViewsParameters.push_back({oneArtist.name(),
-                                       QUrl{QStringLiteral("image://icon/view-media-artist")},
+                                       oneArtist.artistArtURI(),
                                        ViewManager::GridView,
                                        ViewManager::GenericDataModel,
                                        ElisaUtils::FilterByArtist,
                                        oneArtist.databaseId(),
                                        ElisaUtils::Album,
                                        ElisaUtils::Artist,
-                                       QUrl{QStringLiteral("image://icon/media-optical-audio")},
+                                       QUrl{QStringLiteral("image://icon/media-default-album")},
                                        ViewManager::DelegateWithSecondaryText,
                                        ViewManager::ViewShowRating});
     }
@@ -545,7 +548,7 @@ void ViewsListData::refreshEmbeddedCategory()
     {
     case ElisaUtils::Album:
         Q_EMIT dataAboutToBeAdded(3, 3);
-        d->mViewsParameters.insert(3, {{i18nc("Title of the view of all albums", "Albums")},
+        d->mViewsParameters.insert(3, {{i18nc("@title:window Title of the view of all albums", "Albums")},
                                        QUrl{QStringLiteral("image://icon/view-media-album-cover")},
                                        ViewManager::GridView,
                                        ViewManager::GenericDataModel,
@@ -553,10 +556,10 @@ void ViewsListData::refreshEmbeddedCategory()
                                        ElisaUtils::Album,
                                        Qt::DisplayRole,
                                        {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
-                                       {i18n("Title"), i18n("Artist"), i18n("Genre"), i18n("Year")},
+                                       {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"), i18nc("@title:menu", "Year")},
                                        Qt::AscendingOrder,
-                                       {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
-                                       QUrl{QStringLiteral("image://icon/media-optical-audio")},
+                                       {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
+                                       QUrl{QStringLiteral("image://icon/media-default-album")},
                                        ViewManager::DelegateWithSecondaryText,
                                        ViewManager::ViewShowRating,
                                        ViewManager::IsFlatModel});
@@ -564,7 +567,7 @@ void ViewsListData::refreshEmbeddedCategory()
         break;
     case ElisaUtils::Artist:
         Q_EMIT dataAboutToBeAdded(4, 4);
-        d->mViewsParameters.insert(4, {{i18nc("Title of the view of all artists", "Artists")},
+        d->mViewsParameters.insert(4, {{i18nc("@title:window Title of the view of all artists", "Artists")},
                                        QUrl{QStringLiteral("image://icon/view-media-artist")},
                                        ViewManager::GridView,
                                        ViewManager::GenericDataModel,
@@ -572,7 +575,7 @@ void ViewsListData::refreshEmbeddedCategory()
                                        ElisaUtils::Artist,
                                        Qt::DisplayRole,
                                        {Qt::DisplayRole},
-                                       {i18n("Name")},
+                                       {i18nc("@title:menu", "Name")},
                                        Qt::AscendingOrder,
                                        {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
                                        QUrl{QStringLiteral("image://icon/view-media-artist")},
@@ -583,7 +586,7 @@ void ViewsListData::refreshEmbeddedCategory()
         break;
     case ElisaUtils::Genre:
         Q_EMIT dataAboutToBeAdded(6, 6);
-        d->mViewsParameters.insert(6, {{i18nc("Title of the view of all genres", "Genres")},
+        d->mViewsParameters.insert(6, {{i18nc("@title:window Title of the view of all genres", "Genres")},
                                        QUrl{QStringLiteral("image://icon/view-media-genre")},
                                        ViewManager::GridView,
                                        ViewManager::GenericDataModel,
@@ -591,7 +594,7 @@ void ViewsListData::refreshEmbeddedCategory()
                                        ElisaUtils::Genre,
                                        Qt::DisplayRole,
                                        {Qt::DisplayRole},
-                                       {i18n("Genre")},
+                                       {i18nc("@title:menu", "Genre")},
                                        Qt::AscendingOrder,
                                        {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
                                        QUrl{QStringLiteral("image://icon/view-media-genre")},
